@@ -3,7 +3,7 @@ use web_audio_api::context::{AudioContext, BaseAudioContext};
 use web_audio_api::node::{AudioNode, AudioScheduledSourceNode};
 
 fn main() {
-    let context = AudioContext::new(None);
+    let context = AudioContext::default();
 
     let file = File::open("samples/major-scale.ogg").unwrap();
     let buffer = context.decode_audio_data_sync(file).unwrap();
