@@ -97,7 +97,7 @@ impl From<u32> for OscillatorType {
 /// use web_audio_api::context::{BaseAudioContext, AudioContext};
 /// use web_audio_api::node::{AudioNode, AudioScheduledSourceNode};
 ///
-/// let context = AudioContext::new(None);
+/// let context = AudioContext::default();
 ///
 /// let osc = context.create_oscillator();
 /// osc.frequency().set_value(200.);
@@ -133,7 +133,7 @@ impl AudioNode for OscillatorNode {
         &self.registration
     }
 
-    fn channel_config_raw(&self) -> &ChannelConfig {
+    fn channel_config(&self) -> &ChannelConfig {
         &self.channel_config
     }
 
