@@ -101,7 +101,7 @@ impl Default for PannerOptions {
 /// use web_audio_api::node::AudioScheduledSourceNode;
 ///
 /// // Setup a new audio context
-/// let context = AudioContext::new(None);
+/// let context = AudioContext::default();
 ///
 /// // Create a friendly tone
 /// let tone = context.create_oscillator();
@@ -152,7 +152,7 @@ impl AudioNode for PannerNode {
         &self.registration
     }
 
-    fn channel_config_raw(&self) -> &ChannelConfig {
+    fn channel_config(&self) -> &ChannelConfig {
         &self.channel_config
     }
 
@@ -163,6 +163,20 @@ impl AudioNode for PannerNode {
     fn number_of_outputs(&self) -> u32 {
         1
     }
+
+    fn set_channel_count(&self, v: usize) {
+        if v > 2 {
+            panic!("NotSupportedError: PannerNode channel count cannot be greater than two");
+        }
+        self.channel_config.set_count(v);
+    }
+
+    fn set_channel_count_mode(&self, v: ChannelCountMode) {
+        if v == ChannelCountMode::Max {
+            panic!("NotSupportedError: PannerNode channel count mode cannot be set to max");
+        }
+        self.channel_config.set_count_mode(v);
+    }
 }
 
 impl PannerNode {
